diff --git a/lib/modules/platform/github/index.ts b/lib/modules/platform/github/index.ts
index c4f2218951799053a696a6488b2d07a38b892267..309210317668c25b2da4d9aaf43e40a002a35b54 100644
--- a/lib/modules/platform/github/index.ts
+++ b/lib/modules/platform/github/index.ts
@@ -320,9 +320,10 @@ export async function getRawFile(
   branchOrTag?: string,
 ): Promise<string | null> {
   const repo = repoName ?? config.repository;
+  const isSameOrg = repo?.split('/')?.[0] === config.repositoryOwner;
   const httpOptions: InternalHttpOptions = {
-    // Only cache response if it's from the same repo
-    repoCache: repo === config.repository,
+    // Only cache response if it's from the same org
+    repoCache: isSameOrg,
   };
   let url = `repos/${repo}/contents/${fileName}`;
   if (branchOrTag) {